@@ -126,7 +126,7 @@ def factory_args_parse():
         '--template',
         help=u'HTML Template.',
         dest='template',
-        default='default.html'
+        default=None
     )
 
     parser.add_argument(
@@ -213,7 +213,7 @@ def do(path, template, outfile, minify=False, sprite_name=None, doubt=None):
     out_width, out_height = get_image_out_size(images)
 
     css_lines = []
-    css_lines.append('''.icon-%(slug)s { background: url('%(image)s') no-repeat 0 0 } ''' % {
+    css_lines.append('''.icon-%(slug)s { background: url('%(image)s') no-repeat 0 0 !important } ''' % {
         'slug': sprite_name,
         'image': os.path.basename(spirite_image_file)
     })
@@ -253,7 +253,7 @@ def do(path, template, outfile, minify=False, sprite_name=None, doubt=None):
         left += width
         top = 0
 
-    tpl = Template(template.read())
+    tpl = Template(template)
     icon = lambda x: 'icon-%s' % x
     outfile.write(
         tpl.render(
